@@ -18,7 +18,7 @@ import re
 import logging
 import shutil
 from datetime import datetime
-from LbNightlyTools.Utils import log_call as _log_call, find_path
+from LbNightlyTools.Utils import log_call as _log_call, find_path, compatible_lcg_external_files
 try:  # py3
     from shlex import quote
 except ImportError:  # py2
@@ -463,6 +463,28 @@ class cmake_new(object):
             with open(config_log, 'ab') as log:
                 log.write(data)
 
+        if "LCG_EXTERNALS_FILE" in kwargs.get("cache_entries", []):
+            ext_file = kwargs["cache_entries"]["LCG_EXTERNALS_FILE"]
+            # we usually pass "$ENV{BINARY_TAG}" as platform in LCG_EXTERNALS_FILE
+            ext_file = ext_file.replace("$ENV{BINARY_TAG}",
+                                        os.environ['BINARY_TAG'])
+            # find an existing, compatible externals file
+            for ext_file in compatible_lcg_external_files(ext_file):
+                # FIXME: this does not guarantee the file is actually good
+                #        we may have multiple compatible files, but only one
+                #        with the right time and the full list of requirements
+                #        (we should re-run the precondition check to find the
+                #        right match)
+                if os.path.exists(ext_file):
+                    # let's use this one instead of the suggested one
+                    kwargs["cache_entries"]["LCG_EXTERNALS_FILE"] = ext_file
+                    # and make sure we use the required architecture flags
+                    kwargs["cache_entries"]["LHCB_PLATFORM"] = os.environ[
+                        'BINARY_TAG']
+                    kwargs["cache_entries"]["LCG_ARCHITECTURE"] = os.environ[
+                        'BINARY_TAG'].split("-", 1)[0]
+                    break
+
         self._prepare_cache(
             proj,
             cache_entries=kwargs.get('cache_entries'),
