@@ -694,7 +694,8 @@ def git(proj, url=None, commit=None, export=False, merges=None):
         else:
             log.debug('not merged commit %s', merge)
     try:
-        if hasattr(proj, 'slot') and proj.slot and proj.slot.build_id:
+        if hasattr(proj,
+                   'slot') and proj.slot and proj.slot.build_id and not export:
             if not gitlabProjectExists('lhcb-nightlies/{}'.format(proj.name)):
                 raise RuntimeError('lhcb-nightlies/{} does not exist'.format(
                     proj.name))
@@ -784,7 +785,7 @@ def git(proj, url=None, commit=None, export=False, merges=None):
                 else:
                     repo.show_branch('--sha1-name', tag_name(previous=True),
                                      tag_name())
-    except Exception, x:  # pylint: disable=W0703
+    except Exception as x:  # pylint: disable=W0703
         log.warning('failed to record built sources: %s', x)
     return output
 
