@@ -438,6 +438,7 @@ string(REPLACE "$${NIGHTLY_BUILD_ROOT}" "$${CMAKE_CURRENT_LIST_DIR}"
             # if we need to publish the results and it's not a partial build
             self.send({'type': 'drop-build'})
 
+        self.assert_not_aborted()
         self.send({
             'type': 'job-start',
             'host': HOSTNAME,
@@ -480,6 +481,7 @@ string(REPLACE "$${NIGHTLY_BUILD_ROOT}" "$${CMAKE_CURRENT_LIST_DIR}"
 
             def record_start(proj):
                 '''helper function to keep track of the start of the build'''
+                self.assert_not_aborted()
                 # keep a list of the files in the source directories before the build
                 sources[:] = self._sourcesLists(proj)
                 self.send({
@@ -602,6 +604,13 @@ string(REPLACE "$${NIGHTLY_BUILD_ROOT}" "$${CMAKE_CURRENT_LIST_DIR}"
                                  artifacts_dir=self.artifacts_dir),
                              cwd=self.build_dir,
                              checksum='md5')
+                        if os.path.exists(os.path.join(proj.baseDir, 'build')):
+                            self.log.debug("removing %s",
+                                           os.path.join(proj.baseDir, 'build'))
+                            self.tasks.add(
+                                shutil.rmtree,
+                                (os.path.join(proj.baseDir, 'build'), ),
+                                {"ignore_errors": True})
                     else:
                         self.log.warning(
                             '%s missing, binary package not '
