@@ -436,11 +436,26 @@ def createVersionSymlinks(dest, config):
                 with open(join(dest, name, 'CMakeLists.txt')) as cml:
                     data = ''.join(
                         l for l in cml if not l.lstrip().startswith('#'))
-                version = search(
+
+                version = None
+                # try old style CMake configuration
+                version_match = search(
                     r'gaudi_project\(\s*[^\s)]+\s+([^\s)]+)\s*[^)]*\)', data,
                     MULTILINE)
+                if version_match:
+                    version = version_match.group(1)
+                else:  # try new style CMake configuration
+                    version_match = search(
+                        r'project\(\s*[^\s)]+\s+VERSION\s+([\d.]+)\s*[^)]*\)',
+                        data, MULTILINE)
+                    if version_match:  # map X.Y.Z to vXrYpZ
+                        version = ''.join(
+                            a + b
+                            for a, b in zip('vrp',
+                                            version_match.group(1).split(".")))
+
                 if version:
-                    makeVersionLink(dest, name, version.group(1))
+                    makeVersionLink(dest, name, version)
                 else:
                     logging.debug('version not found in %s',
                                   join(dest, name, 'CMakeLists.txt'))
