@@ -158,6 +158,15 @@ def _fromXML(etree):
     return testdict
 
 
+def fullmatch(regex, string, flags=0):
+    """Emulate python 3 re.fullmatch().
+
+    Taken from https://stackoverflow.com/a/30212799/1630648
+
+    """
+    return re.match("(?:" + regex + r")\Z", string, flags=flags)
+
+
 class PeriodicTest(object):
     '''
     Class representing a test, data and associated logic
@@ -256,7 +265,7 @@ class PeriodicTest(object):
             # First checking the builds matching slots
             __log__.debug(self.testgroup +
                           "Checking against build: %s" % buildinfo["slot"])
-            if re.match(self.slot, buildinfo["slot"]):  # pylint: disable=E1101
+            if fullmatch(self.slot, buildinfo["slot"]):  # pylint: disable=E1101
                 # Okay we found a matching slot, now check the projects
                 __log__.debug("Slot matches: " + self.slot)
                 for proj in buildinfo["projects"]:
@@ -265,7 +274,7 @@ class PeriodicTest(object):
                         __log__.debug("Project matches: " + self.project)
                         for platf in buildinfo["platforms"]:
                             # Check with fnmatch for backward compatibility
-                            if (re.match(self.platform, platf)
+                            if (fullmatch(self.platform, platf)
                                     or fnmatch(platf, self.platform)):
 
                                 # Platform matches as well, we can add the
