@@ -657,9 +657,21 @@ ${extraRequires}
         else:
             _txt_version_style = r'v([0-9\*]+)r([0-9\*]+)(?:p([0-9\*]+))?(?:g([0-9\*]+))?'
             m = re.match(_txt_version_style, ver)
-            if m == None:
-                raise Exception("Version '%s' could not be parsed" % ver)
-            (major, minor, patch, gpatch) = m.groups()
+            if m is not None:
+                (major, minor, patch, gpatch) = m.groups()
+            else:
+                # Case when we specify data package versions as point separated numbers
+                _txt_version_point_sep = "(\d+).(\d+)"
+                m = re.match(_txt_version_point_sep, ver)
+                if m is None:
+                    raise Exception(
+                        "Version '%s' for data package %s is not allowed, use *, v*, vXrYpZ or X.Y"
+                        % (ver, pack))
+                else:
+                    (major, minor, patch, gpatch) = m.groups() + (None, None)
+                    # Special case for the '0' which is translated to *
+                    if minor == '0':
+                        minor = '*'
 
         if gpatch != None:
             raise Exception(
